==> imwiki-0.6.2.tar.gz: imwiki-0.6.2/imLib/imMacro/TableOfContents.py <==
# -*- coding: utf8 -*-
import re
import imLib.Category as Category
import imLib.Request as Request

headingPat = re.compile(r'{{{.+?}}}|^(?P<heading_marker>={1,6})[ \t]+(?P<heading>[^\r\n]+?)[ \t]+(?P=heading_marker)[\r]?[\n]?$', re.DOTALL|re.MULTILINE)

def extract(text):
	return filter(lambda obj: obj[0], headingPat.findall(text))

def toRelativeLevel(headingList):
	L = []
	lastLevel = 0
	for markup, text in headingList:
		level = len(markup)
		L.append((level - lastLevel, text))
		lastLevel = level
	return L

def formatting(rHeadingList):
	headingNumber = [0]*6
	L = ['<dl><dt>Table Of Contents</dt>'] # FIXME
	numOfOpened = 0
	for level, text in rHeadingList:
		if level >= 0: markup = '<dd><dl>'
		else: 
			markup = '</dl></dd>'
			#FIXME vvvvvvvvvvvvvvv 더러워. 더러워.
			headingNumber = headingNumber[:numOfOpened+level]
			d= 6-len(headingNumber)
			headingNumber.extend([0]*d)
			#FIXME ^^^^^^^^^^^^^^^
		numOfOpened = numOfOpened + level
 		markup = markup * abs(level)

		#FIXME vvvvvvvvvvvvvvv 더러워. 더러워.
		for index in range(len(headingNumber[:numOfOpened-1])):
			if headingNumber[index] == 0:
				headingNumber[index] = 1
		headingNumber[numOfOpened-1] = headingNumber[numOfOpened-1] + 1
		number = '.'.join(map(str, headingNumber[:numOfOpened]))
		#FIXME ^^^^^^^^^^^^^^^
		L.append('%s<dt><a href="#%s">%s %s</a></dt>' % (markup, text, number, text))
		
	L.append('</dl></dd>' * numOfOpened)
	L.append('</dl>')
	return ''.join(L)

def run():
	request = Request.Request()
	category = Category.getCategoryByCategoryPath(request.categoryPath)
	page = category.getPage(request.pageName)
	headingList = toRelativeLevel(extract(page.rawText))
	return formatting(headingList)

==> imwiki-0.6.3.tar.gz: imwiki-0.6.3/imLib/imMacro/TableOfContents.py <==
# -*- coding: utf8 -*-
import re
import imLib.Category as Category
import imLib.Request as Request

headingPat = re.compile(r'{{{.+?}}}|^(?P<heading_marker>={1,6})[ \t]+(?P<heading>[^\r\n]+?)[ \t]+(?P=heading_marker)[\r]?[\n]?$', re.DOTALL|re.MULTILINE)

def extract(text):
	return filter(lambda obj: obj[0], headingPat.findall(text))

def toRelativeLevel(headingList):
	L = []
	lastLevel = 0
	for markup, text in headingList:
		level = len(markup)
		L.append((level - lastLevel, text))
		lastLevel = level
	return L

def formatting(rHeadingList):
	headingNumber = [0]*6
	L = ['<dl><dt>Table Of Contents</dt>'] # FIXME
	numOfOpened = 0
	for level, text in rHeadingList:
		if level >= 0: markup = '<dd><dl>'
		else: 
			markup = '</dl></dd>'
			#FIXME vvvvvvvvvvvvvvv 더러워. 더러워.
			headingNumber = headingNumber[:numOfOpened+level]
			d= 6-len(headingNumber)
			headingNumber.extend([0]*d)
			#FIXME ^^^^^^^^^^^^^^^
		numOfOpened = numOfOpened + level
 		markup = markup * abs(level)

		#FIXME vvvvvvvvvvvvvvv 더러워. 더러워.
		for index in range(len(headingNumber[:numOfOpened-1])):
			if headingNumber[index] == 0:
				headingNumber[index] = 1
		headingNumber[numOfOpened-1] = headingNumber[numOfOpened-1] + 1
		number = '.'.join(map(str, headingNumber[:numOfOpened]))
		#FIXME ^^^^^^^^^^^^^^^
		L.append('%s<dt><a href="#%s"><small>%s</small> %s</a></dt>' % (markup, text, number, text)) # TODO small보다 좋은거 없나? 
		
	L.append('</dl></dd>' * numOfOpened)
	L.append('</dl>')
	return ''.join(L)

def run():
	request = Request.Request()
	category = Category.getCategoryByCategoryPath(request.categoryPath)
	page = category.getPage(request.pageName)
	headingList = toRelativeLevel(extract(page.rawText))
	return formatting(headingList)
